"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Month = void 0;
const react_1 = __importDefault(require("react"));
const UI_1 = require("../UI");
const contexts_1 = require("../contexts");
const MonthCaption_1 = require("./MonthCaption");
const Week_1 = require("./Week");
const Weekdays_1 = require("./Weekdays");
/**
 * Render the grid with the weekday header row and the weeks for the given
 * month.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function Month(props) {
    const { id, mode, hideWeekdayRow, components, classNames, styles } = (0, contexts_1.useProps)();
    const reactId = react_1.default.useId();
    const captionId = id ? `${id}-caption-${props.index}` : reactId;
    const gridId = id ? `${id}-grid-${props.index}` : reactId;
    const Weekdays = components?.Weekdays ?? Weekdays_1.Weekdays;
    const MonthCaption = components?.MonthCaption ?? MonthCaption_1.MonthCaption;
    const Week = components?.Week ?? Week_1.Week;
    return (react_1.default.createElement("div", { className: classNames[UI_1.UI.MonthWrapper], style: styles?.[UI_1.UI.MonthWrapper] },
        react_1.default.createElement(MonthCaption, { id: captionId, month: props.month, index: props.index }),
        react_1.default.createElement("div", { id: gridId, role: "grid", "aria-multiselectable": mode === "multiple" || mode === "range", "aria-labelledby": captionId, className: classNames[UI_1.UI.Month], style: styles?.[UI_1.UI.Month] },
            react_1.default.createElement(Weekdays, null),
            react_1.default.createElement("div", { role: "rowgroup", className: classNames[UI_1.UI.Weeks], style: styles?.[UI_1.UI.Weeks] }, props.month.weeks.map((week, i) => (react_1.default.createElement(Week, { key: week.weekNumber, week: week, "aria-rowindex": i + (hideWeekdayRow ? 1 : 2) })))))));
}
exports.Month = Month;
//# sourceMappingURL=Month.js.map