"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.YearsDropdown = void 0;
const react_1 = __importDefault(require("react"));
const UI_1 = require("../UI");
const contexts_1 = require("../contexts");
const Dropdown_1 = require("./Dropdown");
/**
 * Render the dropdown to change the year.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function YearsDropdown(props) {
    const { classNames, components, dateLib: { startOfMonth, setYear }, disableNavigation, labels: { labelYearDropdown } } = (0, contexts_1.useProps)();
    const { dropdownOptions, goToMonth } = (0, contexts_1.useCalendar)();
    const handleChange = (e) => {
        const month = setYear(startOfMonth(props.month.date), Number(e.target.value));
        goToMonth(month);
    };
    const Dropdown = components?.Dropdown ?? Dropdown_1.Dropdown;
    return (react_1.default.createElement(Dropdown, { "aria-label": labelYearDropdown(), disabled: Boolean(disableNavigation), rootClassName: classNames[UI_1.UI.YearsDropdown], options: dropdownOptions.years, value: props.month.date.getFullYear(), onChange: handleChange }));
}
exports.YearsDropdown = YearsDropdown;
//# sourceMappingURL=YearsDropdown.js.map