import React, { type ReactElement } from "react";
import type { CalendarWeek, CalendarDay, CalendarMonth } from "../classes";
import type { DropdownOption } from "../components/Dropdown";
export type CalendarContextValue = {
    today: Date;
    /** All the unique dates displayed to the calendar. */
    dates: Date[];
    /**
     * All the days displayed in the calendar. As opposite from
     * {@link CalendarContext.dates}, it may return duplicated dates when shown
     * outside the month.
     */
    days: CalendarDay[];
    /** The months displayed in the calendar. */
    weeks: CalendarWeek[];
    /** The months displayed in the calendar. */
    months: CalendarMonth[];
    /**
     * The month displayed as first the calendar. When `numberOfMonths` is greater
     * than `1`, it is the first of the displayed months.
     */
    firstMonth: Date;
    /** The month displayed as last the calendar. */
    lastMonth: Date;
    /** The next month to display. */
    nextMonth: Date | undefined;
    /** The previous month to display. */
    previousMonth: Date | undefined;
    /** The options to use in the years or months dropdowns. */
    dropdownOptions: {
        /** The options to use in the months dropdown. */
        months: DropdownOption[] | undefined;
        /** The options to use in the years dropdown. */
        years: DropdownOption[] | undefined;
    };
    /** Set the first month displayed in the calendar. */
    setFirstMonth: (date: Date) => void;
    /**
     * Whether the calendar is interactive, i.e. DayPicker has a selection `mode`
     * set or the `onDayClick` prop is set.
     */
    isInteractive: boolean;
    /** Navigate to the specified month. Will fire the `onMonthChange` callback. */
    goToMonth: (month: Date) => void;
    /** Navigate to the next month. */
    goToNextMonth: () => void;
    /** Navigate to the previous month. */
    goToPreviousMonth: () => void;
    /**
     * Navigate to the specified date. If the second parameter (refDate) is
     * provided and the date is before the refDate, then the month is set to one
     * month before the date.
     *
     * @param day - The date to navigate to.
     * @param dateToCompare - Optional. If `date` is before `dateToCompare`, the
     *   month is set to one month before the date.
     */
    goToDay: (day: CalendarDay) => void;
    /** Whether the given date is included in the displayed months. */
    isDayDisplayed: (day: CalendarDay) => boolean;
};
/** @private */
export declare function CalendarContextProvider(props: {
    children: ReactElement;
}): React.JSX.Element;
/**
 * Access to the props passed to `DayPicker`, with some meaningful defaults.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useCalendar(): CalendarContextValue;
