"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCalendar = exports.CalendarContextProvider = void 0;
const react_1 = __importStar(require("react"));
const getDates_1 = require("../helpers/getDates");
const getDays_1 = require("../helpers/getDays");
const getDisplayMonths_1 = require("../helpers/getDisplayMonths");
const getDropdownMonths_1 = require("../helpers/getDropdownMonths");
const getDropdownYears_1 = require("../helpers/getDropdownYears");
const getInitialMonth_1 = require("../helpers/getInitialMonth");
const getMonths_1 = require("../helpers/getMonths");
const getNextMonth_1 = require("../helpers/getNextMonth");
const getPreviousMonth_1 = require("../helpers/getPreviousMonth");
const getWeeks_1 = require("../helpers/getWeeks");
const useControlledValue_1 = require("../helpers/useControlledValue");
const useProps_1 = require("./useProps");
/** @private */
const CalendarContext = (0, react_1.createContext)(undefined);
function useCalendarContextValue() {
    const props = (0, useProps_1.useProps)();
    const { startOfMonth } = props.dateLib;
    const initialDisplayMonth = (0, getInitialMonth_1.getInitialMonth)(props);
    // The first month displayed in the calendar
    const [firstDisplayedMonth, setFirstMonth] = (0, useControlledValue_1.useControlledValue)(initialDisplayMonth, props.month ? startOfMonth(props.month) : undefined);
    /** An array of the months displayed in the calendar. */
    const displayMonths = (0, getDisplayMonths_1.getDisplayMonths)(firstDisplayedMonth, props);
    /** The last month displayed in the calendar. */
    const lastMonth = displayMonths[displayMonths.length - 1];
    /** An array of the dates displayed in the calendar. */
    const dates = (0, getDates_1.getDates)(displayMonths, props.endMonth, props);
    /** An array of the Months displayed in the calendar. */
    const months = (0, getMonths_1.getMonths)(displayMonths, dates, props);
    /** An array of the Weeks displayed in the calendar. */
    const weeks = (0, getWeeks_1.getWeeks)(months);
    /** An array of the Days displayed in the calendar. */
    const days = (0, getDays_1.getDays)(months);
    const previousMonth = (0, getPreviousMonth_1.getPreviousMonth)(firstDisplayedMonth, props);
    const nextMonth = (0, getNextMonth_1.getNextMonth)(firstDisplayedMonth, props);
    const isInteractive = props.mode !== undefined || props.onDayClick !== undefined;
    const { disableNavigation, onMonthChange, startMonth, endMonth } = props;
    function isDayDisplayed(day) {
        return weeks.some((week) => {
            return week.days.some((d) => {
                return d.isEqualTo(day);
            });
        });
    }
    function goToMonth(date) {
        if (disableNavigation) {
            return;
        }
        let newMonth = startOfMonth(date);
        // if month is before startMonth, use the first month instead
        if (startMonth && newMonth < startOfMonth(startMonth)) {
            newMonth = startOfMonth(startMonth);
        }
        // if month is after endMonth, use the last month instead
        if (endMonth && newMonth > startOfMonth(endMonth)) {
            newMonth = startOfMonth(endMonth);
        }
        setFirstMonth(newMonth);
        onMonthChange?.(newMonth);
    }
    function goToDay(day) {
        if (isDayDisplayed(day)) {
            return;
        }
        // TODO:??
        // if (refDate && isBefore(date, refDate)) {
        //   console.log('date is before refDate');
        //   const month = addMonths(date, 1 + dayPicker.numberOfMonths * -1);
        //   console.log('going to month', month);
        //   goToMonth(month);
        // } else {
        //   console.log('going to month', date);
        goToMonth(day.date);
        // }
    }
    function goToNextMonth() {
        return nextMonth ? goToMonth(nextMonth) : undefined;
    }
    function goToPreviousMonth() {
        return previousMonth ? goToMonth(previousMonth) : undefined;
    }
    const calendarContextValue = {
        dates,
        months,
        weeks,
        days,
        today: props.today,
        firstMonth: firstDisplayedMonth,
        lastMonth,
        previousMonth,
        nextMonth,
        setFirstMonth,
        isInteractive,
        dropdownOptions: {
            months: (0, getDropdownMonths_1.getDropdownMonths)(firstDisplayedMonth, props),
            years: (0, getDropdownYears_1.getDropdownYears)(firstDisplayedMonth, props)
        },
        isDayDisplayed,
        goToMonth,
        goToDay,
        goToNextMonth,
        goToPreviousMonth
    };
    return calendarContextValue;
}
/** @private */
function CalendarContextProvider(props) {
    const calendarContextValue = useCalendarContextValue();
    return (react_1.default.createElement(CalendarContext.Provider, { value: calendarContextValue }, props.children));
}
exports.CalendarContextProvider = CalendarContextProvider;
/**
 * Access to the props passed to `DayPicker`, with some meaningful defaults.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useCalendar() {
    const calendarContext = (0, react_1.useContext)(CalendarContext);
    if (!calendarContext) {
        throw new Error("useCalendar() must be used within a CalendarContextProvider");
    }
    return calendarContext;
}
exports.useCalendar = useCalendar;
//# sourceMappingURL=useCalendar.js.map