"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFocus = exports.FocusContextProvider = void 0;
const react_1 = __importStar(require("react"));
const UI_1 = require("../UI");
const getNextFocus_1 = require("../helpers/getNextFocus");
const useCalendar_1 = require("./useCalendar");
const useModifiers_1 = require("./useModifiers");
const useProps_1 = require("./useProps");
const FocusContext = (0, react_1.createContext)(undefined);
function useFocusContextValue() {
    const { goToDay, isDayDisplayed, isInteractive } = (0, useCalendar_1.useCalendar)();
    const props = (0, useProps_1.useProps)();
    const { autoFocus } = props;
    const { dayFlags: internal, selectionStates: selection, getModifiers } = (0, useModifiers_1.useModifiers)();
    const [focused, focus] = (0, react_1.useState)();
    const [lastFocused, setLastFocused] = (0, react_1.useState)();
    const [initiallyFocused, setInitiallyFocused] = (0, react_1.useState)(false);
    const today = internal.today[0];
    let autoFocusTarget;
    const isValidFocusTarget = (day) => {
        return isDayDisplayed(day) && !getModifiers(day)[UI_1.DayFlag.disabled];
    };
    if (isInteractive) {
        if (focused) {
            autoFocusTarget = focused;
        }
        else if (lastFocused) {
            autoFocusTarget = lastFocused;
        }
        else if (selection.selected[0] &&
            isValidFocusTarget(selection.selected[0])) {
            autoFocusTarget = selection.selected[0];
        }
        else if (today && isValidFocusTarget(today)) {
            autoFocusTarget = today;
        }
        else if (internal.focusable[0]) {
            autoFocusTarget = internal.focusable[0];
        }
    }
    // Focus the focus target when autoFocus is passed in
    (0, react_1.useEffect)(() => {
        if (!autoFocus)
            return;
        if (!autoFocusTarget)
            return;
        if (!initiallyFocused)
            return;
        // TODO: bug here?
        setInitiallyFocused(true);
        focus(autoFocusTarget);
    }, [autoFocus, autoFocusTarget, focused, initiallyFocused]);
    const blur = () => {
        setLastFocused(focused);
        focus(undefined);
    };
    function moveFocus(moveBy, moveDir) {
        if (!focused)
            return;
        const nextFocus = (0, getNextFocus_1.getNextFocus)(moveBy, moveDir, focused, props);
        if (!nextFocus)
            return;
        goToDay(nextFocus);
        focus(nextFocus);
    }
    const contextValue = {
        autoFocusTarget,
        initiallyFocused,
        focus,
        focused,
        setLastFocused,
        blur,
        focusDayAfter: () => moveFocus("day", "after"),
        focusDayBefore: () => moveFocus("day", "before"),
        focusWeekAfter: () => moveFocus("week", "after"),
        focusWeekBefore: () => moveFocus("week", "before"),
        focusMonthBefore: () => moveFocus("month", "before"),
        focusMonthAfter: () => moveFocus("month", "after"),
        focusYearBefore: () => moveFocus("year", "before"),
        focusYearAfter: () => moveFocus("year", "after"),
        focusStartOfWeek: () => moveFocus("startOfWeek", "before"),
        focusEndOfWeek: () => moveFocus("endOfWeek", "after")
    };
    return contextValue;
}
/** @private */
function FocusContextProvider({ children }) {
    const focusContextValue = useFocusContextValue();
    return (react_1.default.createElement(FocusContext.Provider, { value: focusContextValue }, children));
}
exports.FocusContextProvider = FocusContextProvider;
/**
 * Share the focused day and the methods to move the focus.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useFocus() {
    const propsContext = (0, react_1.useContext)(FocusContext);
    if (!propsContext) {
        throw new Error("useFocusContext() must be used within a FocusContextProvider");
    }
    return propsContext;
}
exports.useFocus = useFocus;
//# sourceMappingURL=useFocus.js.map