"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useModifiers = exports.ModifiersContextProvider = void 0;
const react_1 = __importStar(require("react"));
const UI_1 = require("../UI");
const useMulti_1 = require("../selection/useMulti");
const useRange_1 = require("../selection/useRange");
const useSingle_1 = require("../selection/useSingle");
const utils_1 = require("../utils");
const dateMatchModifiers_1 = require("../utils/dateMatchModifiers");
const useCalendar_1 = require("./useCalendar");
const useProps_1 = require("./useProps");
/** @private */
const ModifiersContext = (0, react_1.createContext)(undefined);
function useModifiersContextValue() {
    const { dateLib, disabled, hidden, modifiers, mode, onDayClick, showOutsideDays, today } = (0, useProps_1.useProps)();
    const calendar = (0, useCalendar_1.useCalendar)();
    const single = (0, useSingle_1.useSingle)();
    const multi = (0, useMulti_1.useMulti)();
    const range = (0, useRange_1.useRange)();
    const { isSameDay, isSameMonth } = dateLib;
    const internal = {
        [UI_1.DayFlag.focused]: [],
        [UI_1.DayFlag.outside]: [],
        [UI_1.DayFlag.disabled]: [],
        [UI_1.DayFlag.hidden]: [],
        [UI_1.DayFlag.today]: [],
        [UI_1.DayFlag.focusable]: []
    };
    const custom = {};
    const selection = {
        [UI_1.SelectionState.range_end]: [],
        [UI_1.SelectionState.range_middle]: [],
        [UI_1.SelectionState.range_start]: [],
        [UI_1.SelectionState.selected]: []
    };
    for (const day of calendar.days) {
        const { date, displayMonth } = day;
        const isOutside = Boolean(displayMonth && !isSameMonth(date, displayMonth));
        const isDisabled = Boolean(disabled && (0, dateMatchModifiers_1.dateMatchModifiers)(date, disabled, dateLib));
        const isHidden = Boolean(hidden && (0, dateMatchModifiers_1.dateMatchModifiers)(date, hidden, dateLib)) ||
            (!showOutsideDays && isOutside);
        const isElementInteractive = mode || onDayClick !== undefined;
        const isFocusable = isElementInteractive && !isDisabled && !isHidden;
        const isToday = isSameDay(date, today);
        if (isOutside)
            internal.outside.push(day);
        if (isDisabled)
            internal.disabled.push(day);
        if (isHidden)
            internal.hidden.push(day);
        if (isFocusable)
            internal.focusable.push(day);
        if (isToday)
            internal.today.push(day);
        // Add the selection modifiers
        if (mode === "single" && !isDisabled) {
            if (single.isSelected(day.date)) {
                selection[UI_1.SelectionState.selected].push(day);
            }
        }
        if (mode === "multiple" && !isDisabled) {
            if (multi.isSelected(day.date)) {
                selection[UI_1.SelectionState.selected].push(day);
            }
        }
        if (mode === "range" && !isDisabled) {
            if (range.isSelected(day.date)) {
                selection[UI_1.SelectionState.selected].push(day);
                if (range.selected?.from && isSameDay(day.date, range.selected.from)) {
                    if (range.selected?.to)
                        selection[UI_1.SelectionState.range_start].push(day);
                }
                else if (range.selected?.to &&
                    isSameDay(day.date, range.selected.to)) {
                    selection[UI_1.SelectionState.range_end].push(day);
                }
                else if (range.selected &&
                    (0, utils_1.isDateInRange)(day.date, range.selected, dateLib)) {
                    selection[UI_1.SelectionState.range_middle].push(day);
                }
            }
        }
        // Add custom modifiers
        if (modifiers) {
            Object.keys(modifiers).forEach((name) => {
                const modifierValue = modifiers?.[name];
                const isMatch = modifierValue
                    ? (0, dateMatchModifiers_1.dateMatchModifiers)(date, modifierValue, dateLib)
                    : false;
                if (!isMatch)
                    return;
                if (custom[name]) {
                    custom[name].push(day);
                }
                else {
                    custom[name] = [day];
                }
            });
        }
    }
    const getModifiers = (day) => {
        // Initialize all the modifiers to false
        const dayFlags = {
            [UI_1.DayFlag.focused]: false,
            [UI_1.DayFlag.disabled]: false,
            [UI_1.DayFlag.focusable]: false,
            [UI_1.DayFlag.hidden]: false,
            [UI_1.DayFlag.outside]: false,
            [UI_1.DayFlag.today]: false
        };
        const selectionStates = {
            [UI_1.SelectionState.range_end]: false,
            [UI_1.SelectionState.range_middle]: false,
            [UI_1.SelectionState.range_start]: false,
            [UI_1.SelectionState.selected]: false
        };
        const customModifiers = {};
        // Find the modifiers for the given day
        for (const name in internal) {
            const days = internal[name];
            dayFlags[name] = days.some((d) => d === day);
        }
        for (const name in selection) {
            const days = selection[name];
            selectionStates[name] = days.some((d) => d === day);
        }
        for (const name in custom) {
            customModifiers[name] = custom[name].some((d) => d === day);
        }
        return {
            ...selectionStates,
            ...dayFlags,
            // custom modifiers should override all the previous ones
            ...customModifiers
        };
    };
    return {
        dayFlags: internal,
        customModifiers: custom,
        selectionStates: selection,
        getModifiers
    };
}
/** @private */
function ModifiersContextProvider({ children }) {
    const modifiers = useModifiersContextValue();
    return (react_1.default.createElement(ModifiersContext.Provider, { value: modifiers }, children));
}
exports.ModifiersContextProvider = ModifiersContextProvider;
/**
 * Access to the modifiers for the days in the calendar.
 *
 * @group Hooks
 */
function useModifiers() {
    const modifiersContext = (0, react_1.useContext)(ModifiersContext);
    if (!modifiersContext) {
        throw new Error("useModifiersContext() must be used within a ModifiersContextProvider");
    }
    return modifiersContext;
}
exports.useModifiers = useModifiers;
//# sourceMappingURL=useModifiers.js.map