import React from "react";
import type { ClassNames, CustomComponents, DataAttributes, Formatters, Labels, Mode, DayPickerProps, DateLib } from "../types";
export type PropsContextValue = DayPickerProps & {
    /** The mode of the selection. */
    mode: Mode | undefined;
    /** The class names to add to the UI. */
    classNames: ClassNames;
    /** The unique ID of the DayPicker instance. */
    id: string;
    dateLib: DateLib;
    /** The data attributes to add to the calendar. */
    dataAttributes: DataAttributes;
    /** The components used in the UI. */
    components: CustomComponents;
    /** The formatters used in the UI. */
    formatters: Formatters;
    /** The labels used in the UI. */
    labels: Labels;
    /** The number of months displayed in the calendar. */
    numberOfMonths: number;
    /** The date of today. */
    today: Date;
    /** The month where the navigation starts. */
    startMonth: Date | undefined;
    /** The month where the navigation ends. */
    endMonth: Date | undefined;
};
/**
 * Provide the shared props to the DayPicker components. Must be used as root of
 * the other providers.
 *
 * @private
 */
export declare function PropsContextProvider<ModeType extends Mode | undefined = undefined, IsRequired extends boolean = false>({ initialProps, children }: React.PropsWithChildren<{
    initialProps: DayPickerProps;
}>): React.JSX.Element;
/**
 * Access to the props passed to `DayPicker`, with some meaningful defaults.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useProps(): PropsContextValue;
