"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStartEndMonths = void 0;
const lib_1 = require("../lib");
/**
 * Return the `fromMonth` and `toMonth` prop values values parsing the DayPicker
 * props.
 */
function getStartEndMonths(props) {
    let { startMonth, endMonth } = props;
    const { startOfYear, startOfDay, startOfMonth, endOfMonth, addYears, endOfYear, Date } = {
        ...lib_1.dateLib,
        ...props.dateLib
    };
    // Handle deprecated code
    const { fromYear, toYear, fromMonth, toMonth } = props;
    if (!startMonth && fromMonth) {
        startMonth = fromMonth;
    }
    if (!startMonth && fromYear) {
        startMonth = new Date(fromYear, 0, 1);
    }
    if (!endMonth && toMonth) {
        endMonth = toMonth;
    }
    if (!endMonth && toYear) {
        endMonth = new Date(toYear, 11, 31);
    }
    const hasDropdowns = props.captionLayout?.startsWith("dropdown");
    if (startMonth) {
        startMonth = startOfMonth(startMonth);
    }
    else if (fromYear) {
        startMonth = new Date(fromYear, 0, 1);
    }
    else if (!startMonth && hasDropdowns) {
        startMonth = startOfYear(addYears(props.today ?? new Date(), -100));
    }
    if (endMonth) {
        endMonth = endOfMonth(endMonth);
    }
    else if (toYear) {
        endMonth = new Date(toYear, 11, 31);
    }
    else if (!endMonth && hasDropdowns) {
        endMonth = endOfYear(props.today ?? new Date());
    }
    return {
        startMonth: startMonth ? startOfDay(startMonth) : startMonth,
        endMonth: endMonth ? startOfDay(endMonth) : endMonth
    };
}
exports.getStartEndMonths = getStartEndMonths;
//# sourceMappingURL=getStartEndMonths.js.map