import React from "react";
import type { Modifiers, PropsMulti } from "../types";
export type MultiContextValue<T> = {
    setSelected: (triggerDate: Date, modifiers: Modifiers, e: React.MouseEvent | React.KeyboardEvent) => Date[] | undefined;
    isSelected: (date: Date) => boolean;
} & (T extends {
    required: true;
} ? {
    selected: Date[];
} : {
    selected: Date[] | undefined;
});
/** @private */
export declare function MultiProvider(props: React.PropsWithChildren<PropsMulti>): React.JSX.Element;
/**
 * Access to the multi context to get the selected dates or update them.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useMulti<T extends {
    required: boolean;
}>(): MultiContextValue<T>;
