"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMulti = exports.MultiProvider = void 0;
const react_1 = __importDefault(require("react"));
const contexts_1 = require("../contexts");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const MultiContext = react_1.default.createContext(undefined);
function useMultiContextValue({ required = false, min = undefined, max = undefined, selected, onSelect }) {
    const { dateLib: { isSameDay, Date } } = (0, contexts_1.useProps)();
    const [dates, setDates] = react_1.default.useState(selected);
    // Update the selected date if the required flag is set.
    react_1.default.useEffect(() => {
        if (required && dates === undefined)
            setDates([new Date()]);
    }, [required, dates, Date]);
    // Update the selected date if the initialDates changes.
    react_1.default.useEffect(() => {
        if (selected)
            setDates(selected);
    }, [selected]);
    const isSelected = (date) => dates?.some((d) => isSameDay(d, date)) ?? false;
    const setSelected = (triggerDate, modifiers, e) => {
        let newDates = [...(dates ?? [])];
        if (isSelected(triggerDate)) {
            if (dates?.length === min) {
                // Min value reached, do nothing
                return;
            }
            if (required && dates?.length === 1) {
                // Required value already selected do nothing
                return;
            }
            const newDates = dates?.filter((d) => !isSameDay(d, triggerDate));
            setDates(newDates);
        }
        else {
            if (dates?.length === max) {
                // Max value reached, reset the selection to date
                newDates = [triggerDate];
            }
            else {
                // Add the date to the selection
                newDates = [...newDates, triggerDate];
            }
        }
        onSelect?.(newDates, triggerDate, modifiers, e);
        setDates(newDates);
        return newDates;
    };
    return {
        selected: dates,
        setSelected,
        isSelected
    };
}
/** @private */
function MultiProvider(props) {
    const value = useMultiContextValue(props);
    return (react_1.default.createElement(MultiContext.Provider, { value: value }, props.children));
}
exports.MultiProvider = MultiProvider;
/**
 * Access to the multi context to get the selected dates or update them.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useMulti() {
    const context = react_1.default.useContext(MultiContext);
    if (!context) {
        throw new Error("useMulti() must be used within a MultiContextProvider.");
    }
    return context;
}
exports.useMulti = useMulti;
//# sourceMappingURL=useMulti.js.map