"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRange = exports.RangeProvider = void 0;
const react_1 = __importDefault(require("react"));
const contexts_1 = require("../contexts");
const utils_1 = require("../utils");
const isDateInRange_1 = require("../utils/isDateInRange");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const RangeContext = react_1.default.createContext(undefined);
function useRangeContextValue({ required, min, max, selected, onSelect }) {
    const { dateLib } = (0, contexts_1.useProps)();
    const { differenceInCalendarDays } = dateLib;
    const [range, setRange] = react_1.default.useState(selected);
    // Update the selected date if the required flag is set.
    react_1.default.useEffect(() => {
        if (required && range === undefined)
            setRange({ from: undefined, to: undefined });
    }, [required, range]);
    // Update the selected date if the selected changes.
    react_1.default.useEffect(() => {
        if (selected)
            setRange(selected);
    }, [selected]);
    const isSelected = required
        ? (date) => (0, isDateInRange_1.isDateInRange)(date, range, dateLib)
        : (date) => range && (0, isDateInRange_1.isDateInRange)(date, range, dateLib);
    const setSelected = (triggerDate, modifiers, e) => {
        const newRange = triggerDate
            ? (0, utils_1.addToRange)(triggerDate, range, dateLib)
            : undefined;
        if (min) {
            if (newRange?.from &&
                newRange.to &&
                differenceInCalendarDays(newRange.to, newRange.from) < min - 1) {
                newRange.from = triggerDate;
                newRange.to = undefined;
            }
        }
        if (max) {
            if (newRange?.from &&
                newRange.to &&
                differenceInCalendarDays(newRange.to, newRange.from) >= max) {
                newRange.from = triggerDate;
                newRange.to = undefined;
            }
        }
        setRange(newRange);
        onSelect?.(newRange, triggerDate, modifiers, e);
        return newRange;
    };
    return {
        selected: range,
        setSelected,
        isSelected
    };
}
/** @private */
function RangeProvider(props) {
    const value = useRangeContextValue(props);
    return (react_1.default.createElement(RangeContext.Provider, { value: value }, props.children));
}
exports.RangeProvider = RangeProvider;
/**
 * Access to the range context to get the selected range or update it.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useRange() {
    const context = react_1.default.useContext(RangeContext);
    if (!context) {
        throw new Error("useRange() must be used within a RangeContextProvider.");
    }
    return context;
}
exports.useRange = useRange;
//# sourceMappingURL=useRange.js.map