"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSingle = exports.SingleProvider = void 0;
const react_1 = __importDefault(require("react"));
const contexts_1 = require("../contexts");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const SingleContext = react_1.default.createContext(undefined);
function useSingleContextValue({ required = false, selected, onSelect }) {
    const [date, setDate] = react_1.default.useState(selected);
    const { dateLib: { isSameDay, Date } } = (0, contexts_1.useProps)();
    // Update the selected date if the required flag is set.
    react_1.default.useEffect(() => {
        if (required && date === undefined)
            setDate(new Date());
    }, [required, date, Date]);
    // Update the selected date if the selected changes.
    react_1.default.useEffect(() => {
        if (selected)
            setDate(selected);
    }, [selected]);
    const isSelected = (compareDate) => date ? isSameDay(date, compareDate) : false;
    const setSelected = (triggerDate, modifiers, e) => {
        let newDate = triggerDate;
        if (!required && date && date && isSameDay(triggerDate, date)) {
            // If the date is the same, clear the selection.
            newDate = undefined;
        }
        setDate(newDate);
        onSelect?.(newDate, triggerDate, modifiers, e);
        return newDate;
    };
    return { selected: date, setSelected, isSelected };
}
/** @private */
function SingleProvider(props) {
    const value = useSingleContextValue(props);
    return (react_1.default.createElement(SingleContext.Provider, { value: value }, props.children));
}
exports.SingleProvider = SingleProvider;
/**
 * Access to the single context to get the selected date or update it.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useSingle() {
    const context = react_1.default.useContext(SingleContext);
    if (!context) {
        throw new Error("useSingle() must be used within a SingleContextProvider");
    }
    return context;
}
exports.useSingle = useSingle;
//# sourceMappingURL=useSingle.js.map