import React from "react";
import { UI } from "../UI";
import { useProps } from "../contexts";
/**
 * Render the column header with the weekday name (e.g. "Mo", "Tu", etc.).
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function Weekday(props) {
    const { classNames, dateLib, formatters: { formatWeekdayName }, labels: { labelWeekday, labelWeekNumberHeader }, locale, hideWeekdayRow, styles } = useProps();
    return (React.createElement("span", { role: "columnheader", "aria-colindex": props["aria-colindex"], "aria-label": props.weekday
            ? labelWeekday(props.weekday, { locale }, dateLib)
            : labelWeekNumberHeader({ locale }), className: classNames[UI.Weekday], style: styles?.[UI.Weekday] }, !hideWeekdayRow &&
        (props.weekday
            ? formatWeekdayName(props.weekday, { locale }, dateLib)
            : "#")));
}
//# sourceMappingURL=Weekday.js.map