import React, { ReactNode } from "react";
import type { CalendarDay } from "../classes";
import type { Mode } from "../types";
export type FocusContextValue = {
    /** The date that is currently focused. */
    focused: CalendarDay | undefined;
    /**
     * The date that is target of the focus when tabbing into the month grid. The
     * focus target is the selected date first, then the today date, then the
     * first focusable date.
     *
     * @private
     */
    autoFocusTarget: CalendarDay | undefined;
    /**
     * True if the focus is set by the autoFocus prop.
     *
     * @private
     */
    initiallyFocused: boolean;
    /** Focus the given day. */
    focus: (day: CalendarDay | undefined) => void;
    /**
     * Set the last focused day.
     *
     * @private
     */
    setLastFocused: (day: CalendarDay | undefined) => void;
    /** Blur the focused day. */
    blur: () => void;
    /** Focus the day after the focused day. */
    focusDayAfter: () => void;
    /** Focus the day before the focused day. */
    focusDayBefore: () => void;
    /** Focus the day in the week before the focused day. */
    focusWeekBefore: () => void;
    /** Focus the day in the week after the focused day. */
    focusWeekAfter: () => void;
    focusMonthBefore: () => void;
    focusMonthAfter: () => void;
    focusYearBefore: () => void;
    focusYearAfter: () => void;
    focusStartOfWeek: () => void;
    focusEndOfWeek: () => void;
};
/** @private */
export declare function FocusContextProvider<ModeType extends Mode | undefined = undefined, IsRequired extends boolean = false>({ children }: {
    children: ReactNode;
}): React.JSX.Element;
/**
 * Share the focused day and the methods to move the focus.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useFocus(): FocusContextValue;
