import React, { type ReactElement } from "react";
import { DayFlag, SelectionState } from "../UI";
import { CalendarDay } from "../classes";
import type { Modifiers } from "../types";
export type ModifiersContextValue = {
    /** List the days with custom modifiers passed via the `modifiers` prop. */
    customModifiers: Record<string, CalendarDay[]>;
    /** List the days with the internal modifiers. */
    dayFlags: Record<DayFlag, CalendarDay[]>;
    /** List the days with selection modifiers. */
    selectionStates: Record<SelectionState, CalendarDay[]>;
    /** Get the modifiers for a given day. */
    getModifiers: (day: CalendarDay) => Modifiers;
};
/** @private */
export declare function ModifiersContextProvider({ children }: {
    children: ReactElement;
}): React.JSX.Element;
/**
 * Access to the modifiers for the days in the calendar.
 *
 * @group Hooks
 */
export declare function useModifiers(): ModifiersContextValue;
