import React from "react";
import * as customComponents from "../components/custom-components";
import { getDataAttributes } from "../helpers/getDataAttributes";
import { getDefaultClassNames } from "../helpers/getDefaultClassNames";
import { getFormatters } from "../helpers/getFormatters";
import { getStartEndMonths } from "../helpers/getStartEndMonths";
import * as defaultLabels from "../labels";
import { dateLib as defaultDateLib } from "../lib";
const PropsContext = React.createContext(undefined);
function usePropsContextValue(initialProps) {
    const reactId = React.useId();
    const { startMonth, endMonth } = getStartEndMonths(initialProps);
    const dateLib = {
        ...defaultDateLib,
        ...initialProps.dateLib
    };
    const propsContext = {
        ...initialProps,
        startMonth,
        endMonth,
        classNames: {
            ...getDefaultClassNames(),
            ...initialProps.classNames
        },
        components: {
            ...customComponents,
            ...initialProps.components
        },
        dataAttributes: getDataAttributes(initialProps),
        formatters: getFormatters(initialProps.formatters),
        id: initialProps.id ?? reactId,
        labels: {
            ...defaultLabels,
            ...initialProps.labels
        },
        numberOfMonths: initialProps.numberOfMonths ?? 1,
        today: initialProps.today ?? new dateLib.Date(),
        dateLib
    };
    return propsContext;
}
/**
 * Provide the shared props to the DayPicker components. Must be used as root of
 * the other providers.
 *
 * @private
 */
export function PropsContextProvider({ initialProps, children }) {
    const propsContextValue = usePropsContextValue(initialProps);
    return (React.createElement(PropsContext.Provider, { value: propsContextValue }, children));
}
/**
 * Access to the props passed to `DayPicker`, with some meaningful defaults.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function useProps() {
    const propsContext = React.useContext(PropsContext);
    if (!propsContext) {
        throw new Error("usePropsContext() must be used within a PropsContextProvider");
    }
    return propsContext;
}
//# sourceMappingURL=useProps.js.map