import { CalendarDay } from "../classes";
import { dateMatchModifiers } from "../utils/dateMatchModifiers";
import { getPossibleFocusDate } from "./getPossibleFocusDate";
export function getNextFocus(moveBy, moveDir, 
/** The date that is currently focused. */
focused, options, attempt = 0) {
    if (attempt > 365) {
        // Limit the recursion to 365 attempts
        return undefined;
    }
    const possibleFocusDate = getPossibleFocusDate(moveBy, moveDir, focused.date, options);
    const isDisabled = Boolean(options.disabled &&
        dateMatchModifiers(possibleFocusDate, options.disabled, options.dateLib));
    const isHidden = Boolean(options.hidden &&
        dateMatchModifiers(possibleFocusDate, options.hidden, options.dateLib));
    const targetMonth = possibleFocusDate;
    const focusDay = new CalendarDay(possibleFocusDate, targetMonth, options.dateLib);
    if (!isDisabled && !isHidden) {
        return focusDay;
    }
    // Recursively attempt to find the next focusable date
    return getNextFocus(moveBy, moveDir, focusDay, options, attempt + 1);
}
//# sourceMappingURL=getNextFocus.js.map