/** Return the next date that should be focused. */
export function getPossibleFocusDate(moveBy, moveDir, focusedDate, options) {
    const { weekStartsOn, startMonth, endMonth, locale, ISOWeek } = options;
    const { addDays, addMonths, addYears, addWeeks, startOfISOWeek, endOfISOWeek, startOfWeek, endOfWeek, max, min } = options.dateLib;
    const moveFns = {
        day: addDays,
        week: addWeeks,
        month: addMonths,
        year: addYears,
        startOfWeek: (date) => ISOWeek
            ? startOfISOWeek(date)
            : startOfWeek(date, { locale, weekStartsOn }),
        endOfWeek: (date) => ISOWeek ? endOfISOWeek(date) : endOfWeek(date, { locale, weekStartsOn })
    };
    let nextFocusedDate = moveFns[moveBy](focusedDate, moveDir === "after" ? 1 : -1);
    if (moveDir === "before" && startMonth) {
        nextFocusedDate = max([startMonth, nextFocusedDate]);
    }
    else if (moveDir === "after" && endMonth) {
        nextFocusedDate = min([endMonth, nextFocusedDate]);
    }
    return nextFocusedDate;
}
//# sourceMappingURL=getPossibleFocusDate.js.map