import React from "react";
import { useProps } from "../contexts";
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const MultiContext = React.createContext(undefined);
function useMultiContextValue({ required = false, min = undefined, max = undefined, selected, onSelect }) {
    const { dateLib: { isSameDay, Date } } = useProps();
    const [dates, setDates] = React.useState(selected);
    // Update the selected date if the required flag is set.
    React.useEffect(() => {
        if (required && dates === undefined)
            setDates([new Date()]);
    }, [required, dates, Date]);
    // Update the selected date if the initialDates changes.
    React.useEffect(() => {
        if (selected)
            setDates(selected);
    }, [selected]);
    const isSelected = (date) => dates?.some((d) => isSameDay(d, date)) ?? false;
    const setSelected = (triggerDate, modifiers, e) => {
        let newDates = [...(dates ?? [])];
        if (isSelected(triggerDate)) {
            if (dates?.length === min) {
                // Min value reached, do nothing
                return;
            }
            if (required && dates?.length === 1) {
                // Required value already selected do nothing
                return;
            }
            const newDates = dates?.filter((d) => !isSameDay(d, triggerDate));
            setDates(newDates);
        }
        else {
            if (dates?.length === max) {
                // Max value reached, reset the selection to date
                newDates = [triggerDate];
            }
            else {
                // Add the date to the selection
                newDates = [...newDates, triggerDate];
            }
        }
        onSelect?.(newDates, triggerDate, modifiers, e);
        setDates(newDates);
        return newDates;
    };
    return {
        selected: dates,
        setSelected,
        isSelected
    };
}
/** @private */
export function MultiProvider(props) {
    const value = useMultiContextValue(props);
    return (React.createElement(MultiContext.Provider, { value: value }, props.children));
}
/**
 * Access to the multi context to get the selected dates or update them.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function useMulti() {
    const context = React.useContext(MultiContext);
    if (!context) {
        throw new Error("useMulti() must be used within a MultiContextProvider.");
    }
    return context;
}
//# sourceMappingURL=useMulti.js.map