import React from "react";
import { DateRange, Modifiers, PropsRange } from "../types";
export type RangeContextValue<T> = {
    setSelected: (triggerDate: Date, modifiers: Modifiers, e: React.MouseEvent | React.KeyboardEvent) => DateRange | undefined;
    isSelected: (date: Date) => boolean;
} & (T extends {
    required: true;
} ? {
    selected: DateRange;
} : {
    selected: DateRange | undefined;
});
/** @private */
export declare function RangeProvider(props: React.PropsWithChildren<PropsRange>): React.JSX.Element;
/**
 * Access to the range context to get the selected range or update it.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useRange<T extends {
    required: boolean;
}>(): RangeContextValue<T>;
