import React from "react";
import { useProps } from "../contexts";
import { addToRange } from "../utils";
import { isDateInRange } from "../utils/isDateInRange";
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const RangeContext = React.createContext(undefined);
function useRangeContextValue({ required, min, max, selected, onSelect }) {
    const { dateLib } = useProps();
    const { differenceInCalendarDays } = dateLib;
    const [range, setRange] = React.useState(selected);
    // Update the selected date if the required flag is set.
    React.useEffect(() => {
        if (required && range === undefined)
            setRange({ from: undefined, to: undefined });
    }, [required, range]);
    // Update the selected date if the selected changes.
    React.useEffect(() => {
        if (selected)
            setRange(selected);
    }, [selected]);
    const isSelected = required
        ? (date) => isDateInRange(date, range, dateLib)
        : (date) => range && isDateInRange(date, range, dateLib);
    const setSelected = (triggerDate, modifiers, e) => {
        const newRange = triggerDate
            ? addToRange(triggerDate, range, dateLib)
            : undefined;
        if (min) {
            if (newRange?.from &&
                newRange.to &&
                differenceInCalendarDays(newRange.to, newRange.from) < min - 1) {
                newRange.from = triggerDate;
                newRange.to = undefined;
            }
        }
        if (max) {
            if (newRange?.from &&
                newRange.to &&
                differenceInCalendarDays(newRange.to, newRange.from) >= max) {
                newRange.from = triggerDate;
                newRange.to = undefined;
            }
        }
        setRange(newRange);
        onSelect?.(newRange, triggerDate, modifiers, e);
        return newRange;
    };
    return {
        selected: range,
        setSelected,
        isSelected
    };
}
/** @private */
export function RangeProvider(props) {
    const value = useRangeContextValue(props);
    return (React.createElement(RangeContext.Provider, { value: value }, props.children));
}
/**
 * Access to the range context to get the selected range or update it.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function useRange() {
    const context = React.useContext(RangeContext);
    if (!context) {
        throw new Error("useRange() must be used within a RangeContextProvider.");
    }
    return context;
}
//# sourceMappingURL=useRange.js.map